@@ -11,10 +11,7 @@
 (***********************************************************************)
 exception VError of string
 
-module type S = sig  end
-
-
 module Make
     (Dest : OutManager.S) (Image : ImageManager.S)
-    (Scan : Latexscan.S) : S
+    (Scan : Latexscan.S) : Misc.Rien
 
