@@ -13,13 +13,14 @@ module type S =
  functor (Dest : OutManager.S) ->
    functor (Image : ImageManager.S) ->
      functor (Scan : Latexscan.S) ->
-       sig end
+       Misc.Rien
 
 
 module
     Make
     (Dest: OutManager.S) (Image : ImageManager.S) (Scan : Latexscan.S)
     (ToMake : S) =
-struct
-  module Rien = ToMake (Dest) (Image) (Scan)  
-end
+  struct
+    module Rien =  ToMake (Dest) (Image) (Scan)
+    let rien = Rien.rien
+  end
